Summary:	Lightweight, non-caching, optionally anonymizing HTTP proxy
Name:		tinyproxy
Version:	1.11.2
Release:	%mkrel 1
Group:		System/Servers
License:	GPLv2+
URL:		https://tinyproxy.github.io/
Source0:	https://github.com/tinyproxy/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:	tinyproxy.service
Patch0:		tinyproxy-1.8.3-group.patch
BuildRequires:	asciidoc
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	docbook-dtd45-xml
BuildRequires:	systemd
Requires(post): systemd >= %{systemd_required_version}
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description
An anonymizing http proxy which is very light on system resources, ideal for
smaller networks and similar situations where other proxies (such as Squid) may
be overkill and/or a security risk. Tinyproxy can also be configured to
anonymize http requests (allowing for exceptions on a per-header basis).

%prep
%setup -q
%patch -P 0 -p1 -b .group

%build
%configure \
    --enable-xtinyproxy \
    --enable-filter \
    --enable-upstream \
    --enable-transparent \
    --enable-reverse \
    --with-stathost=localhost \
    --program-prefix=""

%make_build

%install
%make_install bindir=%{_sbindir}

# README{.md} is actually an INSTALL file, so we remove it
rm -f %{buildroot}%{_datadir}/doc/%{name}/README*

/bin/touch %{buildroot}%{_sysconfdir}/tinyproxy/filter

mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
mkdir -p %{buildroot}%{_logdir}/tinyproxy
mkdir -p %{buildroot}%{_rundir}/%{name}

install -p -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/tinyproxy.service

/bin/echo "FLAGS=\" -c /etc/tinyproxy/tinyproxy.conf\"" > %{buildroot}%{_sysconfdir}/sysconfig/tinyproxy

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/tinyproxy 0755 root root
EOF

%post
%_tmpfilescreate %{name}
%_post_service tinyproxy

%preun
%_preun_service tinyproxy


%files
%doc docs/*.txt
%doc AUTHORS NEWS TODO
%license COPYING
%{_sbindir}/tinyproxy
%{_unitdir}/tinyproxy.service
%config(noreplace) %{_sysconfdir}/sysconfig/tinyproxy
%dir %{_sysconfdir}/tinyproxy
%config(noreplace) %{_sysconfdir}/tinyproxy/tinyproxy.conf
%config(noreplace) %{_sysconfdir}/tinyproxy/filter
%dir %ghost %attr(0755, root, root) %{_rundir}/%{name}
%ghost %attr(0660, -, -) %{_rundir}/%{name}/tinyproxy.pid
%{_tmpfilesdir}/%{name}.conf
%{_logdir}/tinyproxy/
%{_mandir}/man8/tinyproxy.8*
%{_mandir}/man5/*
%{_datadir}/tinyproxy/


%changelog
* Fri May 17 2024 solbu <solbu> 1.11.2-1.mga10
+ Revision: 2064638
- New release:1.11.2
- Fix license tag

* Tue Apr 16 2024 daviddavid <daviddavid> 1.11.1-1.mga10
+ Revision: 2057834
- new version: 1.11.1
- switch to systemd unit from initscripts

* Sat Mar 19 2022 umeabot <umeabot> 1.10.0-3.mga9
+ Revision: 1799460
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.10.0-2.mga8
+ Revision: 1520228
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 07 2018 solbu <solbu> 1.10.0-1.mga7
+ Revision: 1328840
- Move COPYING to the proper license directory, and don't package the INSTALL file
- New version: 1.10.0
- New upstream URL
- Drop CVE patches 1 and 2: Merged upstream
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
- Mageia 7 Mass Rebuild

* Mon Jul 09 2018 wally <wally> 1.8.3-10.mga7
+ Revision: 1242830
- fix build on aarch64

* Mon Feb 08 2016 umeabot <umeabot> 1.8.3-9.mga6
+ Revision: 946818
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.8.3-8.mga5
+ Revision: 748800
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.3-7.mga5
+ Revision: 689897
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.8.3-6.mga4
+ Revision: 522680
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 1.8.3-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 1.8.3-4.mga3
+ Revision: 384587
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ luigiwalser <luigiwalser>
- add tmpfiles config for /run/tinyproxy

* Fri Nov 02 2012 luigiwalser <luigiwalser> 1.8.3-3.mga3
+ Revision: 312602
- fix pid file in init script
- fix default group ID of processes in tinyproxy.conf

* Wed Oct 24 2012 luigiwalser <luigiwalser> 1.8.3-2.mga3
+ Revision: 309731
- add patches from debian to fix CVE-2012-3505

* Thu Aug 18 2011 misc <misc> 1.8.3-1.mga2
+ Revision: 134307
- fix initscript keyword ( rpmlint rejection)
- upgrade to newer version 1.8.3
- remove ndded part of the spec file
- place each BuildRequires on a line ( easier to spot change )
- remove provides on webproxy ( not required anywhere, and provides
  are not mean to be used for categorization )
- remove Epoch 0 ( breaking upgrade path, but we do not plan to support
  upgrade from 2010.2 or 2011 to mageia 2 )
- imported package tinyproxy

